from setuptools import setup, find_packages
import os

# Read the contents of the README file
with open(os.path.join(os.path.abspath(os.path.dirname(__file__)), "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="autopd",
    version="0.1.0",
    description="AutoPipelineDoctor: AI-powered monitoring, diagnosis, and optimization for ML/AI pipelines",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="AutoPipelineDoctor Team",
    author_email="info@autopipelinedoctor.ai",
    url="https://github.com/autopipelinedoctor/autopd",
    project_urls={
        "Bug Tracker": "https://github.com/autopipelinedoctor/autopd/issues",
        "Documentation": "https://autopipelinedoctor.ai/docs",
        "Source Code": "https://github.com/autopipelinedoctor/autopd",
    },
    packages=find_packages(include=["autopd", "autopd.*"]),
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Monitoring",
    ],
    python_requires=">=3.8",
    install_requires=[
        "numpy>=1.20.0",
        "pandas>=1.3.0",
        "matplotlib>=3.4.0",
        "plotly>=5.0.0",
        "torch>=1.9.0",
        "psutil>=5.8.0",
        "gputil>=1.4.0",
        "py-cpuinfo>=8.0.0",
        "pynvml>=11.0.0",
        "tqdm>=4.60.0",
        "dash>=2.0.0",
        "seaborn>=0.11.0",
        "scikit-learn>=1.0.0",
        "scipy>=1.7.0",
    ],
    extras_require={
        "lightning": ["pytorch-lightning>=1.5.0"],
        "huggingface": ["transformers>=4.5.0"],
        "deepspeed": ["deepspeed>=0.5.0"],
        "llm": [
            "transformers>=4.5.0",
            "openai>=0.27.0",
            "anthropic>=0.3.0",
        ],
        "viz": [
            "dash>=2.0.0",
            "seaborn>=0.11.0",
            "bokeh>=2.4.0",
        ],
        "advanced": [
            "scikit-learn>=1.0.0",
            "scipy>=1.7.0",
            "networkx>=2.6.0",
            "statsmodels>=0.13.0",
            "umap-learn>=0.5.0",
            "hdbscan>=0.8.0",
            "pyro-ppl>=1.7.0",
            "pygraphviz>=1.7",
            "qiskit>=0.30.0",
            "pennylane>=0.20.0",
            "torchviz>=0.0.2",
            "optuna>=2.10.0",
            "ray[tune]>=1.13.0",
            "tensorboardX>=2.5.0",
        ],
        "dev": [
            "pytest>=6.0.0",
            "pytest-cov>=2.12.0",
            "black>=21.5b2",
            "isort>=5.9.0",
            "mypy>=0.812",
            "flake8>=3.9.0",
            "sphinx>=4.0.0",
            "sphinx-rtd-theme>=0.5.0",
            "twine>=3.4.0",
            "build>=0.7.0",
        ],
        "all": [
            "pytorch-lightning>=1.5.0",
            "transformers>=4.5.0",
            "deepspeed>=0.5.0",
            "openai>=0.27.0",
            "anthropic>=0.3.0",
            "bokeh>=2.4.0",
            "networkx>=2.6.0",
            "statsmodels>=0.13.0",
            "umap-learn>=0.5.0",
            "hdbscan>=0.8.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "autopd=autopd.cli:main",
        ],
    },
    keywords="machine learning, deep learning, monitoring, optimization, diagnosis, pytorch, tensorflow, jax, pipeline, AI, ML",
)
